.. _mendeleev:

************************************
Welcome to mendeleev's documentation
************************************


This package provides an API for accessing various properties of elements from
the periodic table of elements.

.. image:: img/mendeleev_periodic_series.png
    :width: 1000px
    :align: center
    :alt: alternate text


.. toctree::
   :caption: Table of Contents
   :maxdepth: 2

   Quick overview <quick>
   Installation <install>
   Tutorials <tutorials>
   Data <data>
   API Reference <code>
   License <license_link>

.. toctree::
   :caption: Changelog
   :maxdepth: 2

   Changes <changes_link>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
